@@ -1,6 +1,9 @@
 import os
+import stat
+from pathlib import Path
 
 import pytest
+from d8s_lists import iterables_have_same_items
 
 from d8s_file_system import (
     directory_create,
@@ -12,6 +15,7 @@ from d8s_file_system import (
     file_delete,
     file_details,
     file_exists,
+    file_extension,
     file_is_executable,
     file_is_readable,
     file_is_writable,
@@ -33,7 +37,6 @@ from d8s_file_system import (
     file_ssdeep,
     file_write,
     is_file,
-    temp_file_create,
 )
 
 NON_EXISTENT_FILE_PATH = './foo'
@@ -61,6 +64,15 @@ def teardown_module():
     directory_delete(TEST_DIRECTORY_PATH)
 
 
+def test_file_extension__docs_1():
+    assert file_extension('foo.py') == '.py'
+    assert file_extension('foo.bar.py') == '.py'
+    assert file_extension('test/foo/bar.py') == '.py'
+    # paths with a leading "." are ignored
+    assert file_extension('.py') == ''
+    assert file_extension('.test/foo.py') == '.py'
+
+
 def test_file_append_1():
     contents = file_read(EXISTING_FILE_PATH)
     assert contents == TEST_FILE_CONTENTS
@@ -71,7 +83,7 @@ def test_file_append_1():
 
 def test_file_copy_1():
     file_copy(EXISTING_FILE_PATH, os.path.join(TEST_DIRECTORY_PATH, 'b'))
-    assert directory_file_names(TEST_DIRECTORY_PATH) == ['a', 'b']
+    assert iterables_have_same_items(directory_file_names(TEST_DIRECTORY_PATH), ['a', 'b'])
 
     # TODO: test the preserve_metadata kwarg (this requires a function to get file metadata)
 
@@ -133,6 +145,10 @@ def test_file_exists_docs_1():
 
 
 def test_file_is_executable_docs_1():
+    f = Path(EXISTING_FILE_PATH)
+    # make the file executable
+    f.chmod(f.stat().st_mode | stat.S_IEXEC)
+
     assert file_is_executable(EXISTING_FILE_PATH)
     assert not file_is_executable(NON_EXISTENT_FILE_PATH)
 
@@ -243,9 +259,3 @@ def test_file_ssdeep_docs_1():
 def test_is_file_docs_1():
     assert is_file(EXISTING_FILE_PATH)
     assert not is_file(NON_EXISTENT_FILE_PATH)
-
-
-def test_temp_file_create_docs_1():
-    temp_file = temp_file_create()
-    assert temp_file
-    temp_file.close()
